version 11.0
log using "C:\matt\working_papers\religion\social\replication\data_analysis\social\social_conservatism.log", replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      social_conservatism.do                          *;
*       Date:           February 15, 2013                               *;
*       Author:         MRG                                             *;
*       Purpose:      	Take social_conservatism.dta and produce the    *;
*                       results in Table 3 as well as support the other *;
*                       quantitative claims made about social           *;
*                       conservatism.                                   *;
* 	    Input File:     social_conservatism.dta                         *;
*       Output File:    social_conservatism.log                         *;
*       Data Output:    none                                            *;             
*       Previous file:  social_conservatism.dta                         *;
*       Machine:        office computer                 				*;
*     ****************************************************************  *;
*     ****************************************************************  *;

set mem 400m;

use "C:\matt\working_papers\religion\social\replication\data_analysis\social\social_conservatism.dta", clear;

set more off;

sum;

desc;

*     ****************************************************************  *;
*       Create a panel ID variable.                                     *;
*     ****************************************************************  *;

egen idn=concat(year ccode);
encode idn, gen(id);

*     ****************************************************************  *;
*       Results for Table 3.                                            *;
*     ****************************************************************  *;

xtreg left_right attend_religious_services hdi attendance_hdi, cluster(id) i(id) theta;

xtreg left_right attend_religious_services hdi attendance_hdi income_level male highest_education age  
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe 
        wave1 wave2 wave3 wave4, cluster(id) i(id) theta;
        
xtreg divorce attend_religious_services hdi attendance_hdi, cluster(id) i(id) theta;

xtreg divorce attend_religious_services hdi attendance_hdi income_level male highest_education age 
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe 
        wave1 wave2 wave3 wave4, cluster(id) i(id) theta;
      
xtreg euthanasia attend_religious_services hdi attendance_hdi, cluster(id) i(id) theta;
        
xtreg euthanasia attend_religious_services hdi attendance_hdi income_level male highest_education age 
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe 
        wave1 wave2 wave3 wave4, cluster(id) i(id) theta;

xtreg abortion attend_religious_services hdi attendance_hdi, cluster(id) i(id) theta;

xtreg abortion attend_religious_services hdi attendance_hdi income_level male highest_education age 
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe 
        wave1 wave2 wave3 wave4, cluster(id) i(id) theta;
        
xtreg suicide attend_religious_services hdi attendance_hdi, cluster(id) i(id) theta;

xtreg suicide attend_religious_services hdi attendance_hdi income_level male highest_education age 
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe 
        wave1 wave2 wave3 wave4, cluster(id) i(id) theta;

xtreg homosexuality attend_religious_services hdi attendance_hdi, cluster(id) i(id) theta;

xtreg homosexuality attend_religious_services hdi attendance_hdi income_level male highest_education age 
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe 
        wave1 wave2 wave3 wave4, cluster(id) i(id) theta;
        
*     ****************************************************************  *;
*     ****************************************************************  *;
*       To find the number of countries and not the country-survey,     *;
*       place the random effects on the country and look at number of   *;
*       groups.                                                         *;
*     ****************************************************************  *;
*     ****************************************************************  *;

xtreg left_right attend_religious_services hdi attendance_hdi, i(ccode) theta;

xtreg left_right attend_religious_services hdi attendance_hdi income_level male highest_education age  
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe 
        wave1 wave2 wave3 wave4, i(ccode) theta;
        
xtreg divorce attend_religious_services hdi attendance_hdi, i(ccode) theta;

xtreg divorce attend_religious_services hdi attendance_hdi income_level male highest_education age 
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe 
        wave1 wave2 wave3 wave4, i(ccode) theta;
      
xtreg euthanasia attend_religious_services hdi attendance_hdi, i(ccode) theta;
        
xtreg euthanasia attend_religious_services hdi attendance_hdi income_level male highest_education age 
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe 
        wave1 wave2 wave3 wave4, i(ccode) theta;

xtreg abortion attend_religious_services hdi attendance_hdi, i(ccode) theta;

xtreg abortion attend_religious_services hdi attendance_hdi income_level male highest_education age 
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe 
        wave1 wave2 wave3 wave4, i(ccode) theta;
        
xtreg suicide attend_religious_services hdi attendance_hdi, i(ccode) theta;

xtreg suicide attend_religious_services hdi attendance_hdi income_level male highest_education age 
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe 
        wave1 wave2 wave3 wave4, i(ccode) theta;

xtreg homosexuality attend_religious_services hdi attendance_hdi, i(ccode) theta;

xtreg homosexuality attend_religious_services hdi attendance_hdi income_level male highest_education age 
        sub_saharan south_asia east_asia se_asia oceania middle_east latin_america north_america east_europe west_europe 
        wave1 wave2 wave3 wave4, i(ccode) theta;
        
*     ****************************************************************  *;
*     ****************************************************************  *;
*       Replication of Table 3 complete                                 *;
*     ****************************************************************  *;
*     ****************************************************************  *;

log close;
        
*     ****************************************************************  *;
*       The End                                                         *;
*     ****************************************************************  *;


